@@ -5,7 +5,7 @@ QUERY__fetch_internal_admin = "SELECT * FROM check_admin"
 QUERY__fetch_recent_passwords_with_ips = "SELECT * FROM fetch_recent_passwords_with_ips WHERE username = :enc_username AND encrypted_address = :encrypted_address;"
 QUERY__fetch_recent_passwords = "SELECT * FROM fetch_recent_passwords WHERE username = :enc_username;"
 QUERY__fetch_recent_passwords_with_account = "SELECT * FROM fetch_recent_passwords WHERE user_id = :user_id;"
-QUERY__create_account = "SELECT create_account(:username, :is_public)"
+QUERY__create_account = "SELECT create_account(:username, :is_public, :attach_as)"
 QUERY__fetch_matching_recent_passwords_with_account = "SELECT * FROM fetch_recent_passwords WHERE user_id = :user_id AND password_id = :password;"
 QUERY__add_password = "INSERT INTO account_password (account, password_hash) VALUES (:account, :password_hash) RETURNING id;"
 QUERY__add_password_cache = "UPDATE account SET password = :password WHERE user_id = :account"
