@@ -1,7 +1,3 @@
-CREATE ROLE registered;
-CREATE ROLE anonymous;
-GRANT anonymous TO registered;
-
 CREATE DOMAIN safe_path AS varchar(255) CHECK (VALUE ~* '^[a-z0-9_\-\/]+(\.[a-zA-Z0-9]+)?$');
 
 -- Install script
@@ -44,7 +40,8 @@ create table email_account (
     host varchar(255) not null,
     port integer not null,
     username varchar(255) not null,
-    encrypted_password text not null
+    encrypted_password text not null,
+    whitelist varchar(2047) not null
 );
 
 create table email_template (
@@ -102,7 +99,7 @@ create table email_template_configuration (
 
 -- account...
 create table account (
-    user_id jaaql_account_id not null default gen_random_uuid(),
+    user_id postgres_addressable_name not null default gen_random_uuid(),
     username character varying(255) not null,
     deleted boolean default false,
     password uuid,
@@ -112,7 +109,7 @@ CREATE UNIQUE INDEX account_unq_email ON account (username);
 -- account_password...
 create table account_password (
     id uuid primary key not null default gen_random_uuid(),
-    account jaaql_account_id not null,
+    account postgres_addressable_name not null,
     password_hash character varying(512) not null,
     created timestamp not null default current_timestamp,
     unique(account, password_hash)
@@ -173,39 +170,23 @@ alter table application_database add constraint application_database__schema
     foreign key (application, schema)
         references application_schema (application, name) ON DELETE CASCADE ON UPDATE CASCADE;
 
-create function account_id_from_username(enc_username text) returns jaaql_account_id as
+create function account_id_from_username(enc_username text) returns postgres_addressable_name as
 $$
 DECLARE
-    account_id jaaql_account_id;
+    account_id postgres_addressable_name;
 BEGIN
     SELECT user_id INTO account_id FROM account WHERE username = enc_username;
     return account_id;
 END
 $$ language plpgsql;
 
-create function attach_account(account_id jaaql_account_id, enc_username text) returns void as
+create function attach_account(account_id postgres_addressable_name, enc_username text) returns void as
 $$
 BEGIN
     INSERT INTO account (username, user_id) VALUES (enc_username, account_id);
 END
 $$ language plpgsql;
 
-create function create_account(enc_username text, is_public boolean = false) returns jaaql_account_id as
-$$
-DECLARE
-    account_id jaaql_account_id;
-BEGIN
-    INSERT INTO account (username) VALUES (enc_username) RETURNING user_id INTO account_id;
-    EXECUTE 'CREATE ROLE ' || quote_ident(account_id);
-    if is_public then
-        EXECUTE 'GRANT anonymous TO ' || quote_ident(account_id);
-    else
-        EXECUTE 'GRANT registered TO ' || quote_ident(account_id);
-    end if;
-    return account_id;
-END
-$$ language plpgsql;
-
 create function close_my_account() returns void as
 $$
 BEGIN
@@ -252,7 +233,7 @@ $$ language plpgsql;
 
 create table account_ip (
     id uuid PRIMARY KEY NOT NULL default gen_random_uuid(),
-    account jaaql_account_id not null,
+    account postgres_addressable_name not null,
     encrypted_address varchar(255),
     first_login timestamptz not null default current_timestamp,
     most_recent_login timestamptz not null default current_timestamp,
@@ -262,7 +243,7 @@ create table account_ip (
 
 create table log (
     id uuid primary key not null default gen_random_uuid(),
-    the_user jaaql_account_id,
+    the_user postgres_addressable_name,
     occurred timestamptz not null default current_timestamp,
     duration_ms integer not null,
     encrypted_exception text,
@@ -334,7 +315,7 @@ create table sign_up (
     code_attempts int default 0 not null,
     activated boolean not null default false,
     used_key_a boolean not null default false,
-    account jaaql_account_id not null,
+    account postgres_addressable_name not null,
     FOREIGN KEY (account) REFERENCES account ON DELETE CASCADE,
     closed timestamptz,
     created timestamptz default current_timestamp not null,
@@ -358,7 +339,7 @@ create table reset_password (
     code_attempts int default 0 not null,
     activated boolean not null default false,
     used_key_a boolean not null default false,
-    the_user jaaql_account_id not null,
+    the_user postgres_addressable_name not null,
     FOREIGN KEY (the_user) REFERENCES account ON DELETE CASCADE,
     closed timestamptz,
     created timestamptz default current_timestamp not null,
@@ -388,7 +369,7 @@ create table email_history (
     application character varying(63) not null,
     override_send_name varchar(255),
     FOREIGN KEY (template, application) REFERENCES email_template(name, application) ON DELETE SET NULL,
-    sender jaaql_account_id not null,
+    sender postgres_addressable_name not null,
     FOREIGN KEY (sender) REFERENCES account ON DELETE CASCADE,
     sent timestamptz not null default current_timestamp,
     encrypted_subject text,
